@@ -3,6 +3,7 @@ from javalang.tree import *
 from javalang.parser import JavaSyntaxError
 
 from javacoder.utils.converter import is_collection
+from javacoder.utils.log import error
 
 
 class JavaCodeGenerator:
@@ -11,6 +12,7 @@ class JavaCodeGenerator:
         self.code_lines = []
         self.current_line = ""
         self.type_stack = []
+        self.success = True
 
     def stack(self, type):
         self.type_stack.append(type)
@@ -38,6 +40,14 @@ class JavaCodeGenerator:
             self.code_lines.append(indent + self.current_line)
             self.current_line = ""
 
+    def generate_document(self, node):
+        if node.documentation:
+            if type(node.documentation) == str:
+                self.add(node.documentation)
+                self.newline()
+            else:
+                self.generate(node.documentation)
+
     def generate(self, node):
         """主生成方法，根据节点类型分发处理"""
         method_name = f"visit_{type(node).__name__}"
@@ -46,6 +56,8 @@ class JavaCodeGenerator:
         else:
             # 默认处理：打印节点类型和位置
             self.add(f"/* UNHANDLED NODE: {type(node).__name__} */")
+            error(f"/* UNHANDLED NODE: {type(node).__name__} */")
+            self.success = False
 
     def get_code(self):
         """返回生成的完整代码"""
@@ -97,7 +109,11 @@ class JavaCodeGenerator:
 
         # document
         if node.documentation:
-            self.generate(node.documentation)
+            if type(node.documentation) == str:
+                self.add(node.documentation)
+                self.newline()
+            else:
+                self.generate(node.documentation)
         # 处理类注解
         self._process_annotations(node.annotations)
 
@@ -150,7 +166,11 @@ class JavaCodeGenerator:
         self.stack('interface[{}]'.format(node.name))
         # document
         if node.documentation:
-            self.generate(node.documentation)
+            if type(node.documentation) == str:
+                self.add(node.documentation)
+                self.newline()
+            else:
+                self.generate(node.documentation)
         # 处理类注解
         self._process_annotations(node.annotations)
 
@@ -220,6 +240,7 @@ class JavaCodeGenerator:
 
     def visit_MethodDeclaration(self, node):
         """处理方法声明，添加注解支持"""
+        self.generate_document(node)
         # 处理方法注解
         self._process_annotations(node.annotations)
 
@@ -259,7 +280,10 @@ class JavaCodeGenerator:
             for i, exc in enumerate(node.throws):
                 if i > 0:
                     self.add(", ")
-                self.generate(exc)
+                if type(exc) == str:
+                    self.add(exc)
+                else:
+                    self.generate(exc)
 
         # 方法体
         if node.body:
@@ -269,7 +293,7 @@ class JavaCodeGenerator:
 
             for stmt in node.body:
                 self.generate(stmt)
-                if not self.current_line.endswith(";"):
+                if len(self.current_line) > 0 and not self.current_line[-1] in (';', '}'):
                     self.add(';')
                 self.newline()
 
@@ -329,7 +353,7 @@ class JavaCodeGenerator:
 
             for stmt in node.body:
                 self.generate(stmt)
-                if not self.current_line.endswith(";"):
+                if len(self.current_line) > 0 and not self.current_line[-1] in (';', '}'):
                     self.add(';')
                 self.newline()
 
@@ -357,12 +381,20 @@ class JavaCodeGenerator:
         self.add(node.name)
 
     def visit_BlockStatement(self, node):
-        if isinstance(node, LocalVariableDeclaration):
-            self.generate(node)
-        elif isinstance(node, Statement):
-            self.generate(node)
+        if isinstance(node.statements, LocalVariableDeclaration):
+            self.generate(node.statements)
+        elif isinstance(node.statements, Statement):
+            self.generate(node.statements)
+        elif is_collection(node.statements):
+            for statement in node.statements:
+                self.generate(statement)
+                if len(self.current_line) > 0 and not self.current_line[-1] in (';', '}'):
+                    self.add(';')
+                self.newline()
         else:
-            self.add(f"/* UNHANDLED BLOCK: {type(node).__name__} */")
+            self.add(f"/* UNHANDLED BLOCK: {type(node.statements).__name__} */")
+            error(f"/* UNHANDLED BLOCK: {type(node.statements).__name__} */")
+            self.success = False
 
     def visit_LocalVariableDeclaration(self, node):
         """处理局部变量声明，添加注解支持"""
@@ -415,6 +447,15 @@ class JavaCodeGenerator:
 
     def visit_BasicType(self, node):
         self.add(node.name)
+        if node.dimensions and len(node.dimensions) > 0:
+            self.add('[')
+            for i, dimension in enumerate(node.dimensions):
+                if dimension == None:
+                    continue
+                if i > 0:
+                    self.add(', ')
+                self.add(str(dimension))
+            self.add(']')
 
     def visit_ReferenceType(self, node):
         if node.arguments:
@@ -429,11 +470,11 @@ class JavaCodeGenerator:
             self.add(node.name)
 
     def visit_Literal(self, node):
-        if node.value is None:
+        if node.value is None or node.value == 'null':
             self.add("null")
         elif isinstance(node.value, str):
-            # null 解析问题
-            if (node.value.startswith('"') and node.value.endswith('"')) or node.value == 'null':
+            # null 解析问题 ,数字转换问题
+            if (node.value.startswith('"') and node.value.endswith('"')):
                 self.add(f"{node.value}")
             else:
                 self.add(f"\"{node.value}\"")
@@ -560,8 +601,23 @@ class JavaCodeGenerator:
             else:
                 self.generate(node.qualifier)
             self.add(".")
+
+        if node.prefix_operators:
+            for operator in node.prefix_operators:
+                if type(operator) == str:
+                    self.add(operator)
+                else:
+                    self.generate(operator)
+
         self.add(node.member)
 
+        if node.postfix_operators:
+            for operator in node.postfix_operators:
+                if type(operator) == str:
+                    self.add(operator)
+                else:
+                    self.generate(operator)
+
     # ====================== 在声明节点中添加注解支持 ======================
 
     def _process_annotations(self, annotations):
@@ -576,6 +632,10 @@ class JavaCodeGenerator:
     def visit_AnnotationMethod(self, node):
         """处理注解方法声明（在注解类型内部）"""
         # 注解方法返回值类型
+        self.generate_document(node)
+
+        self._process_annotations(node.annotations)
+
         self.generate(node.return_type)
         self.add(f" {node.name}()")
 
@@ -604,7 +664,9 @@ class JavaCodeGenerator:
 
     def visit_LambdaExpression(self, node):
         self.add("(")
-        for parameter in node.parameters:
+        for i, parameter in enumerate(node.parameters):
+            if i > 0:
+                self.add(', ')
             self.generate(parameter)
         self.add(") -> ")
         if is_collection(node.body):
@@ -613,7 +675,7 @@ class JavaCodeGenerator:
             self.indent()
             for expression in node.body:
                 self.generate(expression)
-                if not self.current_line.endswith(';'):
+                if len(self.current_line) > 0 and not self.current_line[-1] in (';', '}'):
                     self.add(';')
                 self.newline()
             self.dedent()
@@ -659,14 +721,16 @@ class JavaCodeGenerator:
         # for body_item in node.body:
         if type(node.body[0]) == tuple:
             self.generate(node.body[0][1])
+            self.newline()
         else:
             for body_item in node.body:
                 self.generate(body_item)
                 if type(body_item) == FieldDeclaration:
                     self.add(';')
+                self.newline()
         # if type(node.body[0][1]) == FieldDeclaration:
         #     self.add(';')
-        self.newline()
+        # self.newline()
         # break
 
         self.dedent()
@@ -720,6 +784,280 @@ class JavaCodeGenerator:
             self.generate(initializer)
         self.add('}')
 
+    def visit_ElementArrayValue(self, node):
+        self.add('{')
+        for i, value in enumerate(node.values):
+            if i > 0:
+                self.add(', ')
+            self.generate(value)
+        self.add('}')
+
+    def visit_ClassReference(self, node):
+        self.generate(node.type)
+        self.add('.class')
+
+    def visit_ClassCreator(self, node):
+        self.add('new ')
+        self.generate(node.type)
+        self.add('(')
+        for i, argument in enumerate(node.arguments):
+            if i > 0:
+                self.add(', ')
+            self.generate(argument)
+        self.add(')')
+
+    def visit_BinaryOperation(self, node):
+        self.generate(node.operandl)
+        self.add(f' {node.operator} ')
+        self.generate(node.operandr)
+
+    def visit_TypeArgument(self, node):
+        self.generate(node.type)
+
+    def visit_Cast(self, node):
+        self.add('(')
+        self.generate(node.type)
+        self.add(')')
+        self.generate(node.expression)
+
+    def visit_InferredFormalParameter(self, node):
+        self.add(node.name)
+
+    def visit_ForStatement(self, node):
+        self.add('for (')
+        self.generate(node.control)
+        self.add(') {')
+
+        self.newline()
+        self.indent()
+        self.generate(node.body)
+        self.dedent()
+
+        self.newline()
+        self.add('}')
+
+    def visit_ForControl(self, node):
+        self.generate(node.init)
+        self.add('; ')
+        self.generate(node.condition)
+        self.add('; ')
+        for i, statement in enumerate(node.update):
+            if i > 0:
+                self.add(', ')
+            self.generate(statement)
+
+    def visit_TryStatement(self, node):
+        self.add('try {')
+        self.newline()
+        self.indent()
+
+        for b in node.block:
+            self.generate(b)
+            self.newline()
+        self.dedent()
+        self.add('} ')
+        for catch in node.catches:
+            self.generate(catch)
+
+            self.newline()
+
+        if node.finally_block:
+            self.generate(node.finally_block)
+
+    def visit_VariableDeclaration(self, node):
+        if node.modifiers and len(node.modifiers) > 0:
+            self.add(' '.join(node.modifiers))
+
+        self._process_annotations(node.annotations)
+
+        self.generate(node.type)
+        self.add(' ')
+
+        for declarator in node.declarators:
+            self.generate(declarator)
+
+    def visit_CatchClause(self, node):
+        self.add('catch (')
+        self.generate(node.parameter)
+        self.add(') {')
+        self.newline()
+        self.indent()
+
+        for b in node.block:
+            self.generate(b)
+            if len(self.current_line) > 0 and not self.current_line[-1] in (';', '}'):
+                self.add(';')
+            self.newline()
+        self.dedent()
+        self.newline()
+        self.add('}')
+
+    def visit_CatchClauseParameter(self, node):
+        for i, t in enumerate(node.types):
+            if i > 0:
+                self.add(' | ')
+            if type(t) == str:
+                self.add(t)
+            else:
+                self.generate(t)
+
+        self.add(' ')
+        self.add(node.name)
+
+    def visit_ThrowStatement(self, node):
+        self.add('throw ')
+        self.generate(node.expression)
+        if len(self.current_line) > 0 and not self.current_line[-1] in (';', '}'):
+            self.add(';')
+
+    def visit_MethodReference(self, node):
+        self.generate(node.expression)
+        self.add('::')
+        self.generate(node.method)
+
+    def visit_TernaryExpression(self, node):
+        self.generate(node.condition)
+        self.add(' ? ')
+        self.generate(node.if_true)
+        self.add(' : ')
+        self.generate(node.if_false)
+
+    def visit_EnhancedForControl(self, node):
+        self.generate(node.var)
+        self.add(' : ')
+        self.generate(node.iterable)
+
+    def visit_BreakStatement(self, node):
+        self.add('break;')
+
+    def visit_ArrayCreator(self, node):
+        self.add('new ')
+
+        # if node.qualifier:
+        #     if is_collection(node.qualifier):
+        #         self.add(' '.join(node.qualifier))
+        #     else:
+        #         self.add(node.qualifier)
+
+        self.generate(node.type)
+        self.add('[')
+        if node.dimensions and len(node.dimensions) > 0:
+            for i, dimension in enumerate(node.dimensions):
+                if i > 0:
+                    self.add(', ')
+                self.generate(dimension)
+        self.add(']')
+
+    def visit_ContinueStatement(self, node):
+        self.add('continue;')
+
+    def visit_TypeParameter(self, node):
+        self.add(node.name)
+        if node.extends:
+            self.add(' extends ')
+            self.generate(node.extends)
+
+    def visit_WhileStatement(self, node):
+        self.add('while (')
+        self.generate(node.condition)
+        self.add(') {')
+
+        self.newline()
+        self.indent()
+        self.generate(node.body)
+        self.dedent()
+        self.add('}')
+
+    def visit_DoStatement(self, node):
+        self.add('do {')
+        self.newline()
+        self.indent()
+        self.generate(node.body)
+        self.newline()
+        self.dedent()
+        self.add('} while (')
+        self.generate(node.condition)
+        self.add(')')
+
+    def visit_SuperMethodInvocation(self, node):
+        self.add(f'super.{node.member}')
+        self.add('(')
+        for i, argument in enumerate(node.arguments):
+            if i > 0:
+                self.add(', ')
+            self.generate(argument)
+        self.add(')')
+
+    def visit_NoneType(self, node):
+        self.add('?')
+
+    def visit_SwitchStatement(self, node):
+        self.add('switch (')
+        self.generate(node.expression)
+        self.add(') {')
+        self.newline()
+
+        for case in node.cases:
+            self.indent()
+            self.generate(case)
+            self.dedent()
+
+        self.add('}')
+
+    def visit_SwitchStatementCase(self, node):
+        if node.case and len(node.case) > 0:
+            for i in node.case:
+                self.add(f'case {i}:')
+                self.newline()
+        else:
+            self.add('default:')
+            self.newline()
+        self.indent()
+        for statement in node.statements:
+            self.generate(statement)
+            self.newline()
+        self.dedent()
+
+    def visit_SuperConstructorInvocation(self, node):
+        self.add('super(')
+        for i, argument in enumerate(node.arguments):
+            if i > 0:
+                self.add(', ')
+            self.generate(argument)
+        self.add(')')
+
+    def visit_ConstantDeclaration(self, node):
+        if node.documentation:
+            if type(node.documentation) == str:
+                self.add(node.documentation)
+            else:
+                self.generate(node.documentation)
+            self.newline()
+
+        if node.modifiers:
+            self.add(' '.join(node.modifiers))
+        self.generate(node.type)
+        self.add(' ')
+
+        for i, declarator in enumerate(node.declarators):
+            if i > 0:
+                self.add(', ')
+            self.generate(declarator)
+
+        if len(self.current_line) > 0 and not self.current_line[-1] in (';', '}'):
+            self.add(';')
+
+    def visit_VoidClassReference(self, node):
+        self.add('void.class')
+
+    def visit_ExplicitConstructorInvocation(self, node):
+        self.add('this(')
+        for i, argument in enumerate(node.arguments):
+            if i > 0:
+                self.add(', ')
+            self.generate(argument)
+        self.add(')')
+
 
 def ast_to_source(java_code):
     """将Java代码解析为AST，然后转换回源码"""
